#-----------------------------------------------------------------------------
"""

OneLightPerRender

Sept 4, 2004

Copyright (c) 2004, David G. Drumright (ockham)

Specialized gadget for FyreSpiryt.  Cuts off all but one
light, then renders.  You need to set your render mode
in advance.

"""

#-----------------------------------------------------------------------------

import poser
scene = poser.Scene()

LightList = []
# Holds the initial intensity setting for each, so we can cut
# all to zero and restore properly.
# Fill the list.
for OneActor in scene.Actors():
    if OneActor.IsLight():
        Name=OneActor.InternalName()
        OrigIntens=OneActor.Parameter("Intensity").Value()
        LightList.append((Name,OrigIntens))

# Sort the list.  Reminder: When a list is built of tuples, Python's sort routine
# sorts on the first member of the tuple.  So by putting the name first, we
# can be sure the lights are in numerical order.
LightList.sort()

#------------------------------------------------------------
# For each light in the list: set all others to zero but this one;
# render scene.

for (LeaveAloneName, OrigIntens) in LightList: # Outer loop picks the one to leave on.
    for OneActor in scene.Actors(): # Inner loop turns off all but the leave-alone.
        if not OneActor.IsLight(): continue
        OneName=OneActor.InternalName()
        if OneName==LeaveAloneName: # The one we leave alone: force it to proper value.
            OneActor.Parameter("Intensity").SetValue(OrigIntens)
        else: # Set others to zero
            OneActor.Parameter("Intensity").SetValue(0.0)
    # Now render:
    scene.Render()

# Now restore all
for (OneName, OrigIntens) in LightList:
    OneActor =  scene.ActorByInternalName(OneName)
    OneActor.Parameter("Intensity").SetValue(OrigIntens)

#------------------------------------------------------------
